History
=======

0.1.0 (2021-10-02)
------------------

* First release on PyPI.

0.2.0 (2021-10-04)
------------------

* Added: optional filter by ids
* Added: optional print STAC query
* Updated: docs

0.3.0 (2021-10-06)
------------------

* Breaking Change: ``ui.query_results`` is now a list of ``pystac.item.Item``
* Added: automate builds and tests

0.4.0 (2021-10-08)
------------------

* Breaking Change: ``ui.query_results`` is now a ``VisualList``